<?php

namespace Netzmacher\Tsconf\Misc;

use Netzmacher\Tsconf\Misc\TYPO3versionMisc;
use TYPO3\CMS\Core\Core\Environment;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2020 - Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Class provides methods for the extension manager.
 *
 * @author    Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tsconf
 * @version  10.0.4
 * @since    9.2.0
 */
class TYPO3Icons
{

	/**
	 * @var string
	 */
	private static $_extT3IconsPath = 'EXT:core/Resources/Public/Icons/T3Icons/';

	/**
	 * @var string
	 */
	private static $_T3IconsPath = '/sysext/core/Resources/Public/Icons/T3Icons';

	/**
	 * Get() Get the TYPO3Icons
	 *
	 * @return  array
	 * @access  public
	 * @version 9.2.0
	 * @since   9.2.0
	 */
	public static function Get()
	{
		$extIcons = [];
		$path = self::_path();
//		var_dump( __METHOD__, __LINE__, $path );
//		die();

		if( !is_dir( $path ) )
		{
			return;
		}

		$catDirs = scandir( $path );
		foreach( $catDirs as $catDir )
		{
			switch( true )
			{
				case(!is_dir( $path . '/' . $catDir ) ):
				case($catDir == '.' ):
				case($catDir == '..' ):
				case($catDir == 'overlay' ):
					continue 2;
			}
			$iconFiles = scandir( $path . '/' . $catDir );
			foreach( $iconFiles as $iconFile )
			{
				switch( true )
				{
					case(is_dir( $path . '/' . $catDir . '/' . $iconFile ) ):
						continue 2;
				}
				$path_parts = pathinfo( $iconFile );
				//echo '+ ' . $path_parts[ 'filename' ] . '/' . $path_parts[ 'extension' ], PHP_EOL;
				list($firstpart) = explode( '-', $path_parts[ 'filename' ] );
				$key = substr( $path_parts[ 'filename' ], strlen( $firstpart ) + 1 );
				$extIcons[] = [
						'identifier' => $path_parts[ 'filename' ]
						, 'key' => $key
						, 'label' => $path_parts[ 'filename' ]
						, 'source' => self::$_extT3IconsPath . $iconFile
				];
			}
		}
//		var_dump(__METHOD__, __LINE__, $extIcons);
//		die();
		return $extIcons;
	}

	/**
	 * Full path to the TYPO3Icons main dir
	 *
	 * @return  string
	 * @access  private
	 * @version 10.0.4
	 * @since   9.2.0
	 */
	private static function _path()
	{

		switch( TRUE )
		{
			case(TYPO3versionMisc::Get() < 10004010):
				$path = Environment::getPublicPath() . '/typo3' . self::$_T3IconsPath;
				break;
			case(TYPO3versionMisc::Get() >= 10004010):
			default:
				$path = Environment::getPublicPath() . '/typo3' . self::$_T3IconsPath . '/svgs/';
				break;
		}
		return $path;
	}

}
